/*
 * create sample data for the VA scoped expression
 * use case
 * 
 * data represents sales data (actual and target)
 * Sum of teamMember target can be different to teamTarget
 * Sum of teamTarget can be different to countryTarget
 * 
 */

/*
 * target caslib
 */
%let caslib = casuser;

/*
 * target cas table
 */
%let table = scoped_expression;

/*
 * create CAS session and 
 * create a SAS lib pointing to the Ccaslib
 */
cas sugus sessopts=(metrics=false);
libname &caslib cas caslib="&caslib";

/*
 * create data in work lib
 */
data &table;
  infile cards dlm="," missover;
  input
  country : $2.
  team : $8.
  teamMember : $8.
  actual : 8.
  countryTarget : 8.
  teamTarget : 8.
  teamMemberTarget : 8.
  ;
  format
    actual countryTarget teamTarget teamMemberTarget comma16.
  ;
cards4;
AT,AT_T1,AT_M11,100,5900,580,110
AT,AT_T1,AT_M12,200,5900,580,195
AT,AT_T1,AT_M13,300,5900,580,303
AT,AT_T2,AT_M21,1000,5900,5800,1100
AT,AT_T2,AT_M22,2000,5900,5800,1950
AT,AT_T2,AT_M23,3000,5900,5800,3030
CH,CH_T1,CH_M11,150,5950,585,110
CH,CH_T1,CH_M12,250,5950,585,195
CH,CH_T1,CH_M13,350,5950,585,303
CH,CH_T2,CH_M21,1500,5950,5850,1400
CH,CH_T2,CH_M22,2500,5950,5850,2400
CH,CH_T2,CH_M23,3500,5950,5850,3550
;;;;

proc print data=&table;
run;

/*
 * load SAS data set to a Caslib
 * and save as physical file
 */
proc casutil incaslib="&caslib" outcaslib="&caslib";
  droptable casdata="&table" quiet;
run;
  load data=&table casout="&table" promote;
run;
  save casdata="&table" casout="&table" replace;
run;
quit;